# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api.proto',
  package='org.couchers.api.core',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tapi.proto\x12\x15org.couchers.api.core\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\"\'\n\x14SendFriendRequestReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\"\xc4\x01\n\rFriendRequest\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\x12G\n\x05state\x18\x02 \x01(\x0e\x32\x38.org.couchers.api.core.FriendRequest.FriendRequestStatus\x12\x0f\n\x07user_id\x18\x03 \x01(\x03\x12\x0c\n\x04sent\x18\x04 \x01(\x08\"0\n\x13\x46riendRequestStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\"D\n\x17RespondFriendRequestReq\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"3\n\x16\x43\x61ncelFriendRequestReq\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\"\x83\x01\n\x15ListFriendRequestsRes\x12\x32\n\x04sent\x18\x01 \x03(\x0b\x32$.org.couchers.api.core.FriendRequest\x12\x36\n\x08received\x18\x02 \x03(\x0b\x32$.org.couchers.api.core.FriendRequest\"\"\n\x0eListFriendsRes\x12\x10\n\x08user_ids\x18\x01 \x03(\x03\"\'\n\x14ListMutualFriendsReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\"S\n\x14ListMutualFriendsRes\x12;\n\x0emutual_friends\x18\x01 \x03(\x0b\x32#.org.couchers.api.core.MutualFriend\"\t\n\x07PingReq\"\xcc\x01\n\x07PingRes\x12)\n\x04user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x1c\n\x14unseen_message_count\x18\x02 \x01(\r\x12&\n\x1eunseen_sent_host_request_count\x18\x05 \x01(\r\x12*\n\"unseen_received_host_request_count\x18\x06 \x01(\r\x12$\n\x1cpending_friend_request_count\x18\x04 \x01(\r\"?\n\x0cMutualFriend\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xc6\x01\n\x0fLanguageAbility\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12?\n\x07\x66luency\x18\x02 \x01(\x0e\x32..org.couchers.api.core.LanguageAbility.Fluency\"d\n\x07\x46luency\x12\x13\n\x0f\x46LUENCY_UNKNOWN\x10\x00\x12\x14\n\x10\x46LUENCY_BEGINNER\x10\x01\x12\x1a\n\x16\x46LUENCY_CONVERSATIONAL\x10\x02\x12\x12\n\x0e\x46LUENCY_FLUENT\x10\x03\"5\n\x13NullableUInt32Value\x12\x0f\n\x07is_null\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\r\"3\n\x11NullableBoolValue\x12\x0f\n\x07is_null\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x08\"5\n\x13NullableStringValue\x12\x0f\n\x07is_null\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"\x95\x11\n\x04User\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x10\n\x08hometown\x18\x64 \x01(\t\x12\x10\n\x08timezone\x18z \x01(\t\x12\x0b\n\x03lat\x18! \x01(\x01\x12\x0b\n\x03lng\x18\" \x01(\x01\x12\x0e\n\x06radius\x18# \x01(\x01\x12\x14\n\x0cverification\x18\x05 \x01(\x01\x12\x1a\n\x12\x63ommunity_standing\x18\x06 \x01(\x01\x12\x16\n\x0enum_references\x18\x07 \x01(\r\x12\x0e\n\x06gender\x18\x08 \x01(\t\x12\x10\n\x08pronouns\x18\x65 \x01(\t\x12\x0b\n\x03\x61ge\x18\t \x01(\r\x12*\n\x06joined\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_active\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\r \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\x66 \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x12\n\noccupation\x18\x0e \x01(\t\x12\x11\n\teducation\x18g \x01(\t\x12\x10\n\x08\x61\x62out_me\x18\x0f \x01(\t\x12\x12\n\nmy_travels\x18h \x01(\t\x12\x15\n\rthings_i_like\x18i \x01(\t\x12\x13\n\x0b\x61\x62out_place\x18\x10 \x01(\t\x12\x17\n\x0fregions_visited\x18( \x03(\t\x12\x15\n\rregions_lived\x18) \x03(\t\x12\x1e\n\x16\x61\x64\x64itional_information\x18j \x01(\t\x12=\n\x07\x66riends\x18\x14 \x01(\x0e\x32,.org.couchers.api.core.User.FriendshipStatus\x12\x44\n\x16pending_friend_request\x18$ \x01(\x0b\x32$.org.couchers.api.core.FriendRequest\x12\x30\n\nmax_guests\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0blast_minute\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_pets\x18k \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_pets\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\x0bpet_details\x18l \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08has_kids\x18m \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_kids\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\x0bkid_details\x18n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0ehas_housemates\x18o \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x11housemate_details\x18p \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x15wheelchair_accessible\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0fsmoking_allowed\x18\x1c \x01(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12\x32\n\x0esmokes_at_home\x18q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x64rinking_allowed\x18r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x64rinks_at_home\x18s \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x0fother_host_info\x18t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\x14sleeping_arrangement\x18u \x01(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x36\n\x10sleeping_details\x18v \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x61rea\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bhouse_rules\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x07parking\x18w \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x0fparking_details\x18x \x01(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12.\n\ncamping_ok\x18y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x12\n\navatar_url\x18  \x01(\t\x12\x42\n\x12language_abilities\x18% \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\"E\n\x10\x46riendshipStatus\x12\x0f\n\x0bNOT_FRIENDS\x10\x00\x12\x0b\n\x07\x46RIENDS\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x06\n\x02NA\x10\x03\"\x1a\n\nGetUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"$\n\x13RepeatedStringValue\x12\r\n\x05value\x18\x02 \x03(\t\"U\n\x1cRepeatedLanguageAbilityValue\x12\x35\n\x05value\x18\x01 \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\"\xa7\x15\n\x10UpdateProfileReq\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ity\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x08hometown\x18\x64 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12)\n\x03lat\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12)\n\x03lng\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06radius\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\navatar_key\x18\x19 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12<\n\x08pronouns\x18\x65 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12>\n\noccupation\x18\x04 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12=\n\teducation\x18\x66 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12<\n\x08\x61\x62out_me\x18\x05 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12>\n\nmy_travels\x18g \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12\x41\n\rthings_i_like\x18h \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12?\n\x0b\x61\x62out_place\x18\x06 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12<\n\x0ehosting_status\x18\x08 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18i \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x43\n\x0fregions_visited\x18\x1e \x01(\x0b\x32*.org.couchers.api.core.RepeatedStringValue\x12\x41\n\rregions_lived\x18\x1f \x01(\x0b\x32*.org.couchers.api.core.RepeatedStringValue\x12J\n\x16\x61\x64\x64itional_information\x18j \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12>\n\nmax_guests\x18\x0c \x01(\x0b\x32*.org.couchers.api.core.NullableUInt32Value\x12=\n\x0blast_minute\x18\x0e \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12:\n\x08has_pets\x18k \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12>\n\x0c\x61\x63\x63\x65pts_pets\x18\x0f \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12?\n\x0bpet_details\x18l \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12:\n\x08has_kids\x18m \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12>\n\x0c\x61\x63\x63\x65pts_kids\x18\x10 \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12?\n\x0bkid_details\x18n \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12@\n\x0ehas_housemates\x18o \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12\x45\n\x11housemate_details\x18p \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12G\n\x15wheelchair_accessible\x18\x11 \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12?\n\x0fsmoking_allowed\x18\x12 \x01(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12@\n\x0esmokes_at_home\x18q \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12\x42\n\x10\x64rinking_allowed\x18r \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12@\n\x0e\x64rinks_at_home\x18s \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12\x43\n\x0fother_host_info\x18t \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12H\n\x14sleeping_arrangement\x18u \x01(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x44\n\x10sleeping_details\x18v \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12\x38\n\x04\x61rea\x18\x14 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12?\n\x0bhouse_rules\x18\x15 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12\x39\n\x07parking\x18w \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12>\n\x0fparking_details\x18x \x01(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12<\n\ncamping_ok\x18y \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12O\n\x12language_abilities\x18\x1a \x01(\x0b\x32\x33.org.couchers.api.core.RepeatedLanguageAbilityValue\"X\n\x16InitiateMediaUploadRes\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12*\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\xa0\x01\n\rHostingStatus\x12\x1e\n\x1aHOSTING_STATUS_UNSPECIFIED\x10\x00\x12\x1a\n\x16HOSTING_STATUS_UNKNOWN\x10\x01\x12\x1b\n\x17HOSTING_STATUS_CAN_HOST\x10\x02\x12\x18\n\x14HOSTING_STATUS_MAYBE\x10\x03\x12\x1c\n\x18HOSTING_STATUS_CANT_HOST\x10\x04*\xb8\x01\n\x0cMeetupStatus\x12\x1d\n\x19MEETUP_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15MEETUP_STATUS_UNKNOWN\x10\x01\x12!\n\x1dMEETUP_STATUS_WANTS_TO_MEETUP\x10\x02\x12 \n\x1cMEETUP_STATUS_OPEN_TO_MEETUP\x10\x03\x12)\n%MEETUP_STATUS_DOES_NOT_WANT_TO_MEETUP\x10\x04*\xbf\x01\n\x0fSmokingLocation\x12 \n\x1cSMOKING_LOCATION_UNSPECIFIED\x10\x00\x12\x1c\n\x18SMOKING_LOCATION_UNKNOWN\x10\x01\x12\x18\n\x14SMOKING_LOCATION_YES\x10\x02\x12\x1b\n\x17SMOKING_LOCATION_WINDOW\x10\x03\x12\x1c\n\x18SMOKING_LOCATION_OUTSIDE\x10\x04\x12\x17\n\x13SMOKING_LOCATION_NO\x10\x05*\xed\x01\n\x13SleepingArrangement\x12$\n SLEEPING_ARRANGEMENT_UNSPECIFIED\x10\x00\x12 \n\x1cSLEEPING_ARRANGEMENT_UNKNOWN\x10\x01\x12 \n\x1cSLEEPING_ARRANGEMENT_PRIVATE\x10\x02\x12\x1f\n\x1bSLEEPING_ARRANGEMENT_COMMON\x10\x03\x12$\n SLEEPING_ARRANGEMENT_SHARED_ROOM\x10\x04\x12%\n!SLEEPING_ARRANGEMENT_SHARED_SPACE\x10\x05*\xd4\x01\n\x0eParkingDetails\x12\x1f\n\x1bPARKING_DETAILS_UNSPECIFIED\x10\x00\x12\x1b\n\x17PARKING_DETAILS_UNKNOWN\x10\x01\x12\x1f\n\x1bPARKING_DETAILS_FREE_ONSITE\x10\x02\x12 \n\x1cPARKING_DETAILS_FREE_OFFSITE\x10\x03\x12\x1f\n\x1bPARKING_DETAILS_PAID_ONSITE\x10\x04\x12 \n\x1cPARKING_DETAILS_PAID_OFFSITE\x10\x05\x32\x89\x07\n\x03\x41PI\x12H\n\x04Ping\x12\x1e.org.couchers.api.core.PingReq\x1a\x1e.org.couchers.api.core.PingRes\"\x00\x12K\n\x07GetUser\x12!.org.couchers.api.core.GetUserReq\x1a\x1b.org.couchers.api.core.User\"\x00\x12R\n\rUpdateProfile\x12\'.org.couchers.api.core.UpdateProfileReq\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x11SendFriendRequest\x12+.org.couchers.api.core.SendFriendRequestReq\x1a\x16.google.protobuf.Empty\x12Z\n\x12ListFriendRequests\x12\x16.google.protobuf.Empty\x1a,.org.couchers.api.core.ListFriendRequestsRes\x12L\n\x0bListFriends\x12\x16.google.protobuf.Empty\x1a%.org.couchers.api.core.ListFriendsRes\x12o\n\x11ListMutualFriends\x12+.org.couchers.api.core.ListMutualFriendsReq\x1a+.org.couchers.api.core.ListMutualFriendsRes\"\x00\x12^\n\x14RespondFriendRequest\x12..org.couchers.api.core.RespondFriendRequestReq\x1a\x16.google.protobuf.Empty\x12\\\n\x13\x43\x61ncelFriendRequest\x12-.org.couchers.api.core.CancelFriendRequestReq\x1a\x16.google.protobuf.Empty\x12^\n\x13InitiateMediaUpload\x12\x16.google.protobuf.Empty\x1a-.org.couchers.api.core.InitiateMediaUploadRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])

_HOSTINGSTATUS = _descriptor.EnumDescriptor(
  name='HostingStatus',
  full_name='org.couchers.api.core.HostingStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HOSTING_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOSTING_STATUS_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOSTING_STATUS_CAN_HOST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOSTING_STATUS_MAYBE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOSTING_STATUS_CANT_HOST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6629,
  serialized_end=6789,
)
_sym_db.RegisterEnumDescriptor(_HOSTINGSTATUS)

HostingStatus = enum_type_wrapper.EnumTypeWrapper(_HOSTINGSTATUS)
_MEETUPSTATUS = _descriptor.EnumDescriptor(
  name='MeetupStatus',
  full_name='org.couchers.api.core.MeetupStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEETUP_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEETUP_STATUS_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEETUP_STATUS_WANTS_TO_MEETUP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEETUP_STATUS_OPEN_TO_MEETUP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEETUP_STATUS_DOES_NOT_WANT_TO_MEETUP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6792,
  serialized_end=6976,
)
_sym_db.RegisterEnumDescriptor(_MEETUPSTATUS)

MeetupStatus = enum_type_wrapper.EnumTypeWrapper(_MEETUPSTATUS)
_SMOKINGLOCATION = _descriptor.EnumDescriptor(
  name='SmokingLocation',
  full_name='org.couchers.api.core.SmokingLocation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMOKING_LOCATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOKING_LOCATION_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOKING_LOCATION_YES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOKING_LOCATION_WINDOW', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOKING_LOCATION_OUTSIDE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOKING_LOCATION_NO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6979,
  serialized_end=7170,
)
_sym_db.RegisterEnumDescriptor(_SMOKINGLOCATION)

SmokingLocation = enum_type_wrapper.EnumTypeWrapper(_SMOKINGLOCATION)
_SLEEPINGARRANGEMENT = _descriptor.EnumDescriptor(
  name='SleepingArrangement',
  full_name='org.couchers.api.core.SleepingArrangement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SLEEPING_ARRANGEMENT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLEEPING_ARRANGEMENT_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLEEPING_ARRANGEMENT_PRIVATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLEEPING_ARRANGEMENT_COMMON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLEEPING_ARRANGEMENT_SHARED_ROOM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLEEPING_ARRANGEMENT_SHARED_SPACE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7173,
  serialized_end=7410,
)
_sym_db.RegisterEnumDescriptor(_SLEEPINGARRANGEMENT)

SleepingArrangement = enum_type_wrapper.EnumTypeWrapper(_SLEEPINGARRANGEMENT)
_PARKINGDETAILS = _descriptor.EnumDescriptor(
  name='ParkingDetails',
  full_name='org.couchers.api.core.ParkingDetails',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_DETAILS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_DETAILS_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_DETAILS_FREE_ONSITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_DETAILS_FREE_OFFSITE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_DETAILS_PAID_ONSITE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_DETAILS_PAID_OFFSITE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7413,
  serialized_end=7625,
)
_sym_db.RegisterEnumDescriptor(_PARKINGDETAILS)

ParkingDetails = enum_type_wrapper.EnumTypeWrapper(_PARKINGDETAILS)
HOSTING_STATUS_UNSPECIFIED = 0
HOSTING_STATUS_UNKNOWN = 1
HOSTING_STATUS_CAN_HOST = 2
HOSTING_STATUS_MAYBE = 3
HOSTING_STATUS_CANT_HOST = 4
MEETUP_STATUS_UNSPECIFIED = 0
MEETUP_STATUS_UNKNOWN = 1
MEETUP_STATUS_WANTS_TO_MEETUP = 2
MEETUP_STATUS_OPEN_TO_MEETUP = 3
MEETUP_STATUS_DOES_NOT_WANT_TO_MEETUP = 4
SMOKING_LOCATION_UNSPECIFIED = 0
SMOKING_LOCATION_UNKNOWN = 1
SMOKING_LOCATION_YES = 2
SMOKING_LOCATION_WINDOW = 3
SMOKING_LOCATION_OUTSIDE = 4
SMOKING_LOCATION_NO = 5
SLEEPING_ARRANGEMENT_UNSPECIFIED = 0
SLEEPING_ARRANGEMENT_UNKNOWN = 1
SLEEPING_ARRANGEMENT_PRIVATE = 2
SLEEPING_ARRANGEMENT_COMMON = 3
SLEEPING_ARRANGEMENT_SHARED_ROOM = 4
SLEEPING_ARRANGEMENT_SHARED_SPACE = 5
PARKING_DETAILS_UNSPECIFIED = 0
PARKING_DETAILS_UNKNOWN = 1
PARKING_DETAILS_FREE_ONSITE = 2
PARKING_DETAILS_FREE_OFFSITE = 3
PARKING_DETAILS_PAID_ONSITE = 4
PARKING_DETAILS_PAID_OFFSITE = 5


_FRIENDREQUEST_FRIENDREQUESTSTATUS = _descriptor.EnumDescriptor(
  name='FriendRequestStatus',
  full_name='org.couchers.api.core.FriendRequest.FriendRequestStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=339,
  serialized_end=387,
)
_sym_db.RegisterEnumDescriptor(_FRIENDREQUEST_FRIENDREQUESTSTATUS)

_LANGUAGEABILITY_FLUENCY = _descriptor.EnumDescriptor(
  name='Fluency',
  full_name='org.couchers.api.core.LanguageAbility.Fluency',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLUENCY_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLUENCY_BEGINNER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLUENCY_CONVERSATIONAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLUENCY_FLUENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1190,
  serialized_end=1290,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGEABILITY_FLUENCY)

_USER_FRIENDSHIPSTATUS = _descriptor.EnumDescriptor(
  name='FriendshipStatus',
  full_name='org.couchers.api.core.User.FriendshipStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_FRIENDS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRIENDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3584,
  serialized_end=3653,
)
_sym_db.RegisterEnumDescriptor(_USER_FRIENDSHIPSTATUS)


_SENDFRIENDREQUESTREQ = _descriptor.Descriptor(
  name='SendFriendRequestReq',
  full_name='org.couchers.api.core.SendFriendRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.core.SendFriendRequestReq.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=188,
)


_FRIENDREQUEST = _descriptor.Descriptor(
  name='FriendRequest',
  full_name='org.couchers.api.core.FriendRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friend_request_id', full_name='org.couchers.api.core.FriendRequest.friend_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='org.couchers.api.core.FriendRequest.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.core.FriendRequest.user_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent', full_name='org.couchers.api.core.FriendRequest.sent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FRIENDREQUEST_FRIENDREQUESTSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=387,
)


_RESPONDFRIENDREQUESTREQ = _descriptor.Descriptor(
  name='RespondFriendRequestReq',
  full_name='org.couchers.api.core.RespondFriendRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friend_request_id', full_name='org.couchers.api.core.RespondFriendRequestReq.friend_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept', full_name='org.couchers.api.core.RespondFriendRequestReq.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=457,
)


_CANCELFRIENDREQUESTREQ = _descriptor.Descriptor(
  name='CancelFriendRequestReq',
  full_name='org.couchers.api.core.CancelFriendRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friend_request_id', full_name='org.couchers.api.core.CancelFriendRequestReq.friend_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=510,
)


_LISTFRIENDREQUESTSRES = _descriptor.Descriptor(
  name='ListFriendRequestsRes',
  full_name='org.couchers.api.core.ListFriendRequestsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sent', full_name='org.couchers.api.core.ListFriendRequestsRes.sent', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received', full_name='org.couchers.api.core.ListFriendRequestsRes.received', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=644,
)


_LISTFRIENDSRES = _descriptor.Descriptor(
  name='ListFriendsRes',
  full_name='org.couchers.api.core.ListFriendsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='org.couchers.api.core.ListFriendsRes.user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=680,
)


_LISTMUTUALFRIENDSREQ = _descriptor.Descriptor(
  name='ListMutualFriendsReq',
  full_name='org.couchers.api.core.ListMutualFriendsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.core.ListMutualFriendsReq.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=721,
)


_LISTMUTUALFRIENDSRES = _descriptor.Descriptor(
  name='ListMutualFriendsRes',
  full_name='org.couchers.api.core.ListMutualFriendsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mutual_friends', full_name='org.couchers.api.core.ListMutualFriendsRes.mutual_friends', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=806,
)


_PINGREQ = _descriptor.Descriptor(
  name='PingReq',
  full_name='org.couchers.api.core.PingReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=817,
)


_PINGRES = _descriptor.Descriptor(
  name='PingRes',
  full_name='org.couchers.api.core.PingRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.api.core.PingRes.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unseen_message_count', full_name='org.couchers.api.core.PingRes.unseen_message_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unseen_sent_host_request_count', full_name='org.couchers.api.core.PingRes.unseen_sent_host_request_count', index=2,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unseen_received_host_request_count', full_name='org.couchers.api.core.PingRes.unseen_received_host_request_count', index=3,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_friend_request_count', full_name='org.couchers.api.core.PingRes.pending_friend_request_count', index=4,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=1024,
)


_MUTUALFRIEND = _descriptor.Descriptor(
  name='MutualFriend',
  full_name='org.couchers.api.core.MutualFriend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.core.MutualFriend.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.api.core.MutualFriend.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.core.MutualFriend.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1089,
)


_LANGUAGEABILITY = _descriptor.Descriptor(
  name='LanguageAbility',
  full_name='org.couchers.api.core.LanguageAbility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='org.couchers.api.core.LanguageAbility.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fluency', full_name='org.couchers.api.core.LanguageAbility.fluency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANGUAGEABILITY_FLUENCY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1290,
)


_NULLABLEUINT32VALUE = _descriptor.Descriptor(
  name='NullableUInt32Value',
  full_name='org.couchers.api.core.NullableUInt32Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_null', full_name='org.couchers.api.core.NullableUInt32Value.is_null', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.couchers.api.core.NullableUInt32Value.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1292,
  serialized_end=1345,
)


_NULLABLEBOOLVALUE = _descriptor.Descriptor(
  name='NullableBoolValue',
  full_name='org.couchers.api.core.NullableBoolValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_null', full_name='org.couchers.api.core.NullableBoolValue.is_null', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.couchers.api.core.NullableBoolValue.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1347,
  serialized_end=1398,
)


_NULLABLESTRINGVALUE = _descriptor.Descriptor(
  name='NullableStringValue',
  full_name='org.couchers.api.core.NullableStringValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_null', full_name='org.couchers.api.core.NullableStringValue.is_null', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.couchers.api.core.NullableStringValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1453,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='org.couchers.api.core.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.core.User.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.api.core.User.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.core.User.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.api.core.User.city', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hometown', full_name='org.couchers.api.core.User.hometown', index=4,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='org.couchers.api.core.User.timezone', index=5,
      number=122, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.api.core.User.lat', index=6,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.api.core.User.lng', index=7,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.api.core.User.radius', index=8,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verification', full_name='org.couchers.api.core.User.verification', index=9,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='community_standing', full_name='org.couchers.api.core.User.community_standing', index=10,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_references', full_name='org.couchers.api.core.User.num_references', index=11,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.api.core.User.gender', index=12,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pronouns', full_name='org.couchers.api.core.User.pronouns', index=13,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='age', full_name='org.couchers.api.core.User.age', index=14,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joined', full_name='org.couchers.api.core.User.joined', index=15,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_active', full_name='org.couchers.api.core.User.last_active', index=16,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosting_status', full_name='org.couchers.api.core.User.hosting_status', index=17,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meetup_status', full_name='org.couchers.api.core.User.meetup_status', index=18,
      number=102, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupation', full_name='org.couchers.api.core.User.occupation', index=19,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='education', full_name='org.couchers.api.core.User.education', index=20,
      number=103, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about_me', full_name='org.couchers.api.core.User.about_me', index=21,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='my_travels', full_name='org.couchers.api.core.User.my_travels', index=22,
      number=104, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='things_i_like', full_name='org.couchers.api.core.User.things_i_like', index=23,
      number=105, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about_place', full_name='org.couchers.api.core.User.about_place', index=24,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regions_visited', full_name='org.couchers.api.core.User.regions_visited', index=25,
      number=40, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regions_lived', full_name='org.couchers.api.core.User.regions_lived', index=26,
      number=41, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_information', full_name='org.couchers.api.core.User.additional_information', index=27,
      number=106, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends', full_name='org.couchers.api.core.User.friends', index=28,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_friend_request', full_name='org.couchers.api.core.User.pending_friend_request', index=29,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_guests', full_name='org.couchers.api.core.User.max_guests', index=30,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_minute', full_name='org.couchers.api.core.User.last_minute', index=31,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_pets', full_name='org.couchers.api.core.User.has_pets', index=32,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_pets', full_name='org.couchers.api.core.User.accepts_pets', index=33,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pet_details', full_name='org.couchers.api.core.User.pet_details', index=34,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_kids', full_name='org.couchers.api.core.User.has_kids', index=35,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_kids', full_name='org.couchers.api.core.User.accepts_kids', index=36,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kid_details', full_name='org.couchers.api.core.User.kid_details', index=37,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_housemates', full_name='org.couchers.api.core.User.has_housemates', index=38,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='housemate_details', full_name='org.couchers.api.core.User.housemate_details', index=39,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelchair_accessible', full_name='org.couchers.api.core.User.wheelchair_accessible', index=40,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smoking_allowed', full_name='org.couchers.api.core.User.smoking_allowed', index=41,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smokes_at_home', full_name='org.couchers.api.core.User.smokes_at_home', index=42,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drinking_allowed', full_name='org.couchers.api.core.User.drinking_allowed', index=43,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drinks_at_home', full_name='org.couchers.api.core.User.drinks_at_home', index=44,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_host_info', full_name='org.couchers.api.core.User.other_host_info', index=45,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sleeping_arrangement', full_name='org.couchers.api.core.User.sleeping_arrangement', index=46,
      number=117, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sleeping_details', full_name='org.couchers.api.core.User.sleeping_details', index=47,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area', full_name='org.couchers.api.core.User.area', index=48,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='house_rules', full_name='org.couchers.api.core.User.house_rules', index=49,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking', full_name='org.couchers.api.core.User.parking', index=50,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_details', full_name='org.couchers.api.core.User.parking_details', index=51,
      number=120, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camping_ok', full_name='org.couchers.api.core.User.camping_ok', index=52,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_url', full_name='org.couchers.api.core.User.avatar_url', index=53,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_abilities', full_name='org.couchers.api.core.User.language_abilities', index=54,
      number=37, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USER_FRIENDSHIPSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=3653,
)


_GETUSERREQ = _descriptor.Descriptor(
  name='GetUserReq',
  full_name='org.couchers.api.core.GetUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.api.core.GetUserReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3655,
  serialized_end=3681,
)


_REPEATEDSTRINGVALUE = _descriptor.Descriptor(
  name='RepeatedStringValue',
  full_name='org.couchers.api.core.RepeatedStringValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.couchers.api.core.RepeatedStringValue.value', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3683,
  serialized_end=3719,
)


_REPEATEDLANGUAGEABILITYVALUE = _descriptor.Descriptor(
  name='RepeatedLanguageAbilityValue',
  full_name='org.couchers.api.core.RepeatedLanguageAbilityValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.couchers.api.core.RepeatedLanguageAbilityValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3721,
  serialized_end=3806,
)


_UPDATEPROFILEREQ = _descriptor.Descriptor(
  name='UpdateProfileReq',
  full_name='org.couchers.api.core.UpdateProfileReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.core.UpdateProfileReq.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.api.core.UpdateProfileReq.city', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hometown', full_name='org.couchers.api.core.UpdateProfileReq.hometown', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.api.core.UpdateProfileReq.lat', index=3,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.api.core.UpdateProfileReq.lng', index=4,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.api.core.UpdateProfileReq.radius', index=5,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_key', full_name='org.couchers.api.core.UpdateProfileReq.avatar_key', index=6,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pronouns', full_name='org.couchers.api.core.UpdateProfileReq.pronouns', index=7,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupation', full_name='org.couchers.api.core.UpdateProfileReq.occupation', index=8,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='education', full_name='org.couchers.api.core.UpdateProfileReq.education', index=9,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about_me', full_name='org.couchers.api.core.UpdateProfileReq.about_me', index=10,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='my_travels', full_name='org.couchers.api.core.UpdateProfileReq.my_travels', index=11,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='things_i_like', full_name='org.couchers.api.core.UpdateProfileReq.things_i_like', index=12,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about_place', full_name='org.couchers.api.core.UpdateProfileReq.about_place', index=13,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosting_status', full_name='org.couchers.api.core.UpdateProfileReq.hosting_status', index=14,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meetup_status', full_name='org.couchers.api.core.UpdateProfileReq.meetup_status', index=15,
      number=105, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regions_visited', full_name='org.couchers.api.core.UpdateProfileReq.regions_visited', index=16,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regions_lived', full_name='org.couchers.api.core.UpdateProfileReq.regions_lived', index=17,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_information', full_name='org.couchers.api.core.UpdateProfileReq.additional_information', index=18,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_guests', full_name='org.couchers.api.core.UpdateProfileReq.max_guests', index=19,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_minute', full_name='org.couchers.api.core.UpdateProfileReq.last_minute', index=20,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_pets', full_name='org.couchers.api.core.UpdateProfileReq.has_pets', index=21,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_pets', full_name='org.couchers.api.core.UpdateProfileReq.accepts_pets', index=22,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pet_details', full_name='org.couchers.api.core.UpdateProfileReq.pet_details', index=23,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_kids', full_name='org.couchers.api.core.UpdateProfileReq.has_kids', index=24,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_kids', full_name='org.couchers.api.core.UpdateProfileReq.accepts_kids', index=25,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kid_details', full_name='org.couchers.api.core.UpdateProfileReq.kid_details', index=26,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_housemates', full_name='org.couchers.api.core.UpdateProfileReq.has_housemates', index=27,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='housemate_details', full_name='org.couchers.api.core.UpdateProfileReq.housemate_details', index=28,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelchair_accessible', full_name='org.couchers.api.core.UpdateProfileReq.wheelchair_accessible', index=29,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smoking_allowed', full_name='org.couchers.api.core.UpdateProfileReq.smoking_allowed', index=30,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smokes_at_home', full_name='org.couchers.api.core.UpdateProfileReq.smokes_at_home', index=31,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drinking_allowed', full_name='org.couchers.api.core.UpdateProfileReq.drinking_allowed', index=32,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drinks_at_home', full_name='org.couchers.api.core.UpdateProfileReq.drinks_at_home', index=33,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_host_info', full_name='org.couchers.api.core.UpdateProfileReq.other_host_info', index=34,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sleeping_arrangement', full_name='org.couchers.api.core.UpdateProfileReq.sleeping_arrangement', index=35,
      number=117, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sleeping_details', full_name='org.couchers.api.core.UpdateProfileReq.sleeping_details', index=36,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area', full_name='org.couchers.api.core.UpdateProfileReq.area', index=37,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='house_rules', full_name='org.couchers.api.core.UpdateProfileReq.house_rules', index=38,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking', full_name='org.couchers.api.core.UpdateProfileReq.parking', index=39,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_details', full_name='org.couchers.api.core.UpdateProfileReq.parking_details', index=40,
      number=120, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camping_ok', full_name='org.couchers.api.core.UpdateProfileReq.camping_ok', index=41,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_abilities', full_name='org.couchers.api.core.UpdateProfileReq.language_abilities', index=42,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3809,
  serialized_end=6536,
)


_INITIATEMEDIAUPLOADRES = _descriptor.Descriptor(
  name='InitiateMediaUploadRes',
  full_name='org.couchers.api.core.InitiateMediaUploadRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_url', full_name='org.couchers.api.core.InitiateMediaUploadRes.upload_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='org.couchers.api.core.InitiateMediaUploadRes.expiry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6538,
  serialized_end=6626,
)

_FRIENDREQUEST.fields_by_name['state'].enum_type = _FRIENDREQUEST_FRIENDREQUESTSTATUS
_FRIENDREQUEST_FRIENDREQUESTSTATUS.containing_type = _FRIENDREQUEST
_LISTFRIENDREQUESTSRES.fields_by_name['sent'].message_type = _FRIENDREQUEST
_LISTFRIENDREQUESTSRES.fields_by_name['received'].message_type = _FRIENDREQUEST
_LISTMUTUALFRIENDSRES.fields_by_name['mutual_friends'].message_type = _MUTUALFRIEND
_PINGRES.fields_by_name['user'].message_type = _USER
_LANGUAGEABILITY.fields_by_name['fluency'].enum_type = _LANGUAGEABILITY_FLUENCY
_LANGUAGEABILITY_FLUENCY.containing_type = _LANGUAGEABILITY
_USER.fields_by_name['joined'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USER.fields_by_name['last_active'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USER.fields_by_name['hosting_status'].enum_type = _HOSTINGSTATUS
_USER.fields_by_name['meetup_status'].enum_type = _MEETUPSTATUS
_USER.fields_by_name['friends'].enum_type = _USER_FRIENDSHIPSTATUS
_USER.fields_by_name['pending_friend_request'].message_type = _FRIENDREQUEST
_USER.fields_by_name['max_guests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_USER.fields_by_name['last_minute'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['has_pets'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['accepts_pets'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['pet_details'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['has_kids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['accepts_kids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['kid_details'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['has_housemates'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['housemate_details'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['wheelchair_accessible'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['smoking_allowed'].enum_type = _SMOKINGLOCATION
_USER.fields_by_name['smokes_at_home'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['drinking_allowed'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['drinks_at_home'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['other_host_info'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['sleeping_arrangement'].enum_type = _SLEEPINGARRANGEMENT
_USER.fields_by_name['sleeping_details'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['area'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['house_rules'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USER.fields_by_name['parking'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['parking_details'].enum_type = _PARKINGDETAILS
_USER.fields_by_name['camping_ok'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USER.fields_by_name['language_abilities'].message_type = _LANGUAGEABILITY
_USER_FRIENDSHIPSTATUS.containing_type = _USER
_REPEATEDLANGUAGEABILITYVALUE.fields_by_name['value'].message_type = _LANGUAGEABILITY
_UPDATEPROFILEREQ.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['hometown'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['lat'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_UPDATEPROFILEREQ.fields_by_name['lng'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_UPDATEPROFILEREQ.fields_by_name['radius'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_UPDATEPROFILEREQ.fields_by_name['avatar_key'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['pronouns'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['occupation'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['education'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['about_me'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['my_travels'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['things_i_like'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['about_place'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['hosting_status'].enum_type = _HOSTINGSTATUS
_UPDATEPROFILEREQ.fields_by_name['meetup_status'].enum_type = _MEETUPSTATUS
_UPDATEPROFILEREQ.fields_by_name['regions_visited'].message_type = _REPEATEDSTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['regions_lived'].message_type = _REPEATEDSTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['additional_information'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['max_guests'].message_type = _NULLABLEUINT32VALUE
_UPDATEPROFILEREQ.fields_by_name['last_minute'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['has_pets'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['accepts_pets'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['pet_details'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['has_kids'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['accepts_kids'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['kid_details'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['has_housemates'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['housemate_details'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['wheelchair_accessible'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['smoking_allowed'].enum_type = _SMOKINGLOCATION
_UPDATEPROFILEREQ.fields_by_name['smokes_at_home'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['drinking_allowed'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['drinks_at_home'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['other_host_info'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['sleeping_arrangement'].enum_type = _SLEEPINGARRANGEMENT
_UPDATEPROFILEREQ.fields_by_name['sleeping_details'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['area'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['house_rules'].message_type = _NULLABLESTRINGVALUE
_UPDATEPROFILEREQ.fields_by_name['parking'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['parking_details'].enum_type = _PARKINGDETAILS
_UPDATEPROFILEREQ.fields_by_name['camping_ok'].message_type = _NULLABLEBOOLVALUE
_UPDATEPROFILEREQ.fields_by_name['language_abilities'].message_type = _REPEATEDLANGUAGEABILITYVALUE
_INITIATEMEDIAUPLOADRES.fields_by_name['expiry'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['SendFriendRequestReq'] = _SENDFRIENDREQUESTREQ
DESCRIPTOR.message_types_by_name['FriendRequest'] = _FRIENDREQUEST
DESCRIPTOR.message_types_by_name['RespondFriendRequestReq'] = _RESPONDFRIENDREQUESTREQ
DESCRIPTOR.message_types_by_name['CancelFriendRequestReq'] = _CANCELFRIENDREQUESTREQ
DESCRIPTOR.message_types_by_name['ListFriendRequestsRes'] = _LISTFRIENDREQUESTSRES
DESCRIPTOR.message_types_by_name['ListFriendsRes'] = _LISTFRIENDSRES
DESCRIPTOR.message_types_by_name['ListMutualFriendsReq'] = _LISTMUTUALFRIENDSREQ
DESCRIPTOR.message_types_by_name['ListMutualFriendsRes'] = _LISTMUTUALFRIENDSRES
DESCRIPTOR.message_types_by_name['PingReq'] = _PINGREQ
DESCRIPTOR.message_types_by_name['PingRes'] = _PINGRES
DESCRIPTOR.message_types_by_name['MutualFriend'] = _MUTUALFRIEND
DESCRIPTOR.message_types_by_name['LanguageAbility'] = _LANGUAGEABILITY
DESCRIPTOR.message_types_by_name['NullableUInt32Value'] = _NULLABLEUINT32VALUE
DESCRIPTOR.message_types_by_name['NullableBoolValue'] = _NULLABLEBOOLVALUE
DESCRIPTOR.message_types_by_name['NullableStringValue'] = _NULLABLESTRINGVALUE
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['GetUserReq'] = _GETUSERREQ
DESCRIPTOR.message_types_by_name['RepeatedStringValue'] = _REPEATEDSTRINGVALUE
DESCRIPTOR.message_types_by_name['RepeatedLanguageAbilityValue'] = _REPEATEDLANGUAGEABILITYVALUE
DESCRIPTOR.message_types_by_name['UpdateProfileReq'] = _UPDATEPROFILEREQ
DESCRIPTOR.message_types_by_name['InitiateMediaUploadRes'] = _INITIATEMEDIAUPLOADRES
DESCRIPTOR.enum_types_by_name['HostingStatus'] = _HOSTINGSTATUS
DESCRIPTOR.enum_types_by_name['MeetupStatus'] = _MEETUPSTATUS
DESCRIPTOR.enum_types_by_name['SmokingLocation'] = _SMOKINGLOCATION
DESCRIPTOR.enum_types_by_name['SleepingArrangement'] = _SLEEPINGARRANGEMENT
DESCRIPTOR.enum_types_by_name['ParkingDetails'] = _PARKINGDETAILS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendFriendRequestReq = _reflection.GeneratedProtocolMessageType('SendFriendRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _SENDFRIENDREQUESTREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.SendFriendRequestReq)
  })
_sym_db.RegisterMessage(SendFriendRequestReq)

FriendRequest = _reflection.GeneratedProtocolMessageType('FriendRequest', (_message.Message,), {
  'DESCRIPTOR' : _FRIENDREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.FriendRequest)
  })
_sym_db.RegisterMessage(FriendRequest)

RespondFriendRequestReq = _reflection.GeneratedProtocolMessageType('RespondFriendRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _RESPONDFRIENDREQUESTREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.RespondFriendRequestReq)
  })
_sym_db.RegisterMessage(RespondFriendRequestReq)

CancelFriendRequestReq = _reflection.GeneratedProtocolMessageType('CancelFriendRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _CANCELFRIENDREQUESTREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.CancelFriendRequestReq)
  })
_sym_db.RegisterMessage(CancelFriendRequestReq)

ListFriendRequestsRes = _reflection.GeneratedProtocolMessageType('ListFriendRequestsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTFRIENDREQUESTSRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.ListFriendRequestsRes)
  })
_sym_db.RegisterMessage(ListFriendRequestsRes)

ListFriendsRes = _reflection.GeneratedProtocolMessageType('ListFriendsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTFRIENDSRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.ListFriendsRes)
  })
_sym_db.RegisterMessage(ListFriendsRes)

ListMutualFriendsReq = _reflection.GeneratedProtocolMessageType('ListMutualFriendsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTMUTUALFRIENDSREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.ListMutualFriendsReq)
  })
_sym_db.RegisterMessage(ListMutualFriendsReq)

ListMutualFriendsRes = _reflection.GeneratedProtocolMessageType('ListMutualFriendsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTMUTUALFRIENDSRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.ListMutualFriendsRes)
  })
_sym_db.RegisterMessage(ListMutualFriendsRes)

PingReq = _reflection.GeneratedProtocolMessageType('PingReq', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.PingReq)
  })
_sym_db.RegisterMessage(PingReq)

PingRes = _reflection.GeneratedProtocolMessageType('PingRes', (_message.Message,), {
  'DESCRIPTOR' : _PINGRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.PingRes)
  })
_sym_db.RegisterMessage(PingRes)

MutualFriend = _reflection.GeneratedProtocolMessageType('MutualFriend', (_message.Message,), {
  'DESCRIPTOR' : _MUTUALFRIEND,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.MutualFriend)
  })
_sym_db.RegisterMessage(MutualFriend)

LanguageAbility = _reflection.GeneratedProtocolMessageType('LanguageAbility', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGEABILITY,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.LanguageAbility)
  })
_sym_db.RegisterMessage(LanguageAbility)

NullableUInt32Value = _reflection.GeneratedProtocolMessageType('NullableUInt32Value', (_message.Message,), {
  'DESCRIPTOR' : _NULLABLEUINT32VALUE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.NullableUInt32Value)
  })
_sym_db.RegisterMessage(NullableUInt32Value)

NullableBoolValue = _reflection.GeneratedProtocolMessageType('NullableBoolValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLABLEBOOLVALUE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.NullableBoolValue)
  })
_sym_db.RegisterMessage(NullableBoolValue)

NullableStringValue = _reflection.GeneratedProtocolMessageType('NullableStringValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLABLESTRINGVALUE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.NullableStringValue)
  })
_sym_db.RegisterMessage(NullableStringValue)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.User)
  })
_sym_db.RegisterMessage(User)

GetUserReq = _reflection.GeneratedProtocolMessageType('GetUserReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.GetUserReq)
  })
_sym_db.RegisterMessage(GetUserReq)

RepeatedStringValue = _reflection.GeneratedProtocolMessageType('RepeatedStringValue', (_message.Message,), {
  'DESCRIPTOR' : _REPEATEDSTRINGVALUE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.RepeatedStringValue)
  })
_sym_db.RegisterMessage(RepeatedStringValue)

RepeatedLanguageAbilityValue = _reflection.GeneratedProtocolMessageType('RepeatedLanguageAbilityValue', (_message.Message,), {
  'DESCRIPTOR' : _REPEATEDLANGUAGEABILITYVALUE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.RepeatedLanguageAbilityValue)
  })
_sym_db.RegisterMessage(RepeatedLanguageAbilityValue)

UpdateProfileReq = _reflection.GeneratedProtocolMessageType('UpdateProfileReq', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROFILEREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.UpdateProfileReq)
  })
_sym_db.RegisterMessage(UpdateProfileReq)

InitiateMediaUploadRes = _reflection.GeneratedProtocolMessageType('InitiateMediaUploadRes', (_message.Message,), {
  'DESCRIPTOR' : _INITIATEMEDIAUPLOADRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.core.InitiateMediaUploadRes)
  })
_sym_db.RegisterMessage(InitiateMediaUploadRes)



_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='org.couchers.api.core.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=7628,
  serialized_end=8533,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='org.couchers.api.core.API.Ping',
    index=0,
    containing_service=None,
    input_type=_PINGREQ,
    output_type=_PINGRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUser',
    full_name='org.couchers.api.core.API.GetUser',
    index=1,
    containing_service=None,
    input_type=_GETUSERREQ,
    output_type=_USER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProfile',
    full_name='org.couchers.api.core.API.UpdateProfile',
    index=2,
    containing_service=None,
    input_type=_UPDATEPROFILEREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFriendRequest',
    full_name='org.couchers.api.core.API.SendFriendRequest',
    index=3,
    containing_service=None,
    input_type=_SENDFRIENDREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFriendRequests',
    full_name='org.couchers.api.core.API.ListFriendRequests',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTFRIENDREQUESTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFriends',
    full_name='org.couchers.api.core.API.ListFriends',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTFRIENDSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMutualFriends',
    full_name='org.couchers.api.core.API.ListMutualFriends',
    index=6,
    containing_service=None,
    input_type=_LISTMUTUALFRIENDSREQ,
    output_type=_LISTMUTUALFRIENDSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RespondFriendRequest',
    full_name='org.couchers.api.core.API.RespondFriendRequest',
    index=7,
    containing_service=None,
    input_type=_RESPONDFRIENDREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelFriendRequest',
    full_name='org.couchers.api.core.API.CancelFriendRequest',
    index=8,
    containing_service=None,
    input_type=_CANCELFRIENDREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InitiateMediaUpload',
    full_name='org.couchers.api.core.API.InitiateMediaUpload',
    index=9,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_INITIATEMEDIAUPLOADRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: media.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='media.proto',
  package='org.couchers.media',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bmedia.proto\x12\x12org.couchers.media\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf1\x01\n\rUploadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x04type\x18\x02 \x01(\x0e\x32,.org.couchers.media.UploadRequest.UploadType\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmax_width\x18\x05 \x01(\r\x12\x12\n\nmax_height\x18\x06 \x01(\r\"\x17\n\nUploadType\x12\t\n\x05IMAGE\x10\x00\"6\n\x15UploadConfirmationReq\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t2b\n\x05Media\x12Y\n\x12UploadConfirmation\x12).org.couchers.media.UploadConfirmationReq\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_UPLOADREQUEST_UPLOADTYPE = _descriptor.EnumDescriptor(
  name='UploadType',
  full_name='org.couchers.media.UploadRequest.UploadType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=316,
  serialized_end=339,
)
_sym_db.RegisterEnumDescriptor(_UPLOADREQUEST_UPLOADTYPE)


_UPLOADREQUEST = _descriptor.Descriptor(
  name='UploadRequest',
  full_name='org.couchers.media.UploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='org.couchers.media.UploadRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='org.couchers.media.UploadRequest.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.media.UploadRequest.created', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='org.couchers.media.UploadRequest.expiry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_width', full_name='org.couchers.media.UploadRequest.max_width', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_height', full_name='org.couchers.media.UploadRequest.max_height', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPLOADREQUEST_UPLOADTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=339,
)


_UPLOADCONFIRMATIONREQ = _descriptor.Descriptor(
  name='UploadConfirmationReq',
  full_name='org.couchers.media.UploadConfirmationReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='org.couchers.media.UploadConfirmationReq.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='org.couchers.media.UploadConfirmationReq.filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=395,
)

_UPLOADREQUEST.fields_by_name['type'].enum_type = _UPLOADREQUEST_UPLOADTYPE
_UPLOADREQUEST.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPLOADREQUEST.fields_by_name['expiry'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPLOADREQUEST_UPLOADTYPE.containing_type = _UPLOADREQUEST
DESCRIPTOR.message_types_by_name['UploadRequest'] = _UPLOADREQUEST
DESCRIPTOR.message_types_by_name['UploadConfirmationReq'] = _UPLOADCONFIRMATIONREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadRequest = _reflection.GeneratedProtocolMessageType('UploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADREQUEST,
  '__module__' : 'media_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.media.UploadRequest)
  })
_sym_db.RegisterMessage(UploadRequest)

UploadConfirmationReq = _reflection.GeneratedProtocolMessageType('UploadConfirmationReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADCONFIRMATIONREQ,
  '__module__' : 'media_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.media.UploadConfirmationReq)
  })
_sym_db.RegisterMessage(UploadConfirmationReq)



_MEDIA = _descriptor.ServiceDescriptor(
  name='Media',
  full_name='org.couchers.media.Media',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=397,
  serialized_end=495,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadConfirmation',
    full_name='org.couchers.media.Media.UploadConfirmation',
    index=0,
    containing_service=None,
    input_type=_UPLOADCONFIRMATIONREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MEDIA)

DESCRIPTOR.services_by_name['Media'] = _MEDIA

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/httpbody.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/httpbody.proto',
  package='google.api',
  syntax='proto3',
  serialized_options=b'\n\016com.google.apiB\rHttpBodyProtoP\001Z;google.golang.org/genproto/googleapis/api/httpbody;httpbody\370\001\001\242\002\004GAPI',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19google/api/httpbody.proto\x12\ngoogle.api\x1a\x19google/protobuf/any.proto\"X\n\x08HttpBody\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12(\n\nextensions\x18\x03 \x03(\x0b\x32\x14.google.protobuf.AnyBh\n\x0e\x63om.google.apiB\rHttpBodyProtoP\x01Z;google.golang.org/genproto/googleapis/api/httpbody;httpbody\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_HTTPBODY = _descriptor.Descriptor(
  name='HttpBody',
  full_name='google.api.HttpBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_type', full_name='google.api.HttpBody.content_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='google.api.HttpBody.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='google.api.HttpBody.extensions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=156,
)

_HTTPBODY.fields_by_name['extensions'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['HttpBody'] = _HTTPBODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpBody = _reflection.GeneratedProtocolMessageType('HttpBody', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBODY,
  '__module__' : 'google.api.httpbody_pb2'
  # @@protoc_insertion_point(class_scope:google.api.HttpBody)
  })
_sym_db.RegisterMessage(HttpBody)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
